@@ -1,6 +1,6 @@
 #' Tokenization of Character Variables
 #'
-#' [step_tokenize()] creates a *specification* of a recipe step that will
+#' `step_tokenize()` creates a *specification* of a recipe step that will
 #' convert a character predictor into a [`token`][tokenlist()] variable.
 #'
 #' @template args-recipe
@@ -285,14 +285,15 @@ prep.step_tokenize <- function(x, training, info = NULL, ...) {
 
   tokenizers <- list()
 
-  for (i in seq_along(col_names)) {
-    text <- training[, col_names[[i]], drop = TRUE]
+  for (col_name in col_names) {
+    text <- training[[col_name]]
 
     if (x$engine == "tokenizers.bpe" & !is.null(x$training_options$vocab_size)) {
-      check_bpe_vocab_size(text, x$training_options$vocab_size, col_names[[i]])
+      check_bpe_vocab_size(text, x$training_options$vocab_size, col_name)
     }
 
-    tokenizers[[i]] <- x$custom_token %||% tokenizer_switch(x$token, x, text)
+    tokenizers[[col_name]] <- x$custom_token %||% 
+      tokenizer_switch(x$token, x, text)
   }
 
   step_tokenize_new(
@@ -315,12 +316,16 @@ bake.step_tokenize <- function(object, new_data, ...) {
   col_names <- object$columns
   check_new_data(col_names, object, new_data)
 
-  for (i in seq_along(col_names)) {
-    new_data[, col_names[i]] <- tokenizer_fun(
-      data = new_data[, col_names[i]],
-      name = col_names[i],
+  if (is.null(names(object$custom_token))) {
+    # Backwards compatibility with 1.0.3 (#230)
+    names(object$custom_token) <- col_names
+  }
+  
+  for (col_name in col_names) {
+    new_data[[col_name]] <- tokenizer_fun(
+      x = new_data[[col_name]],
       options = object$options,
-      token = object$custom_token[[i]]
+      token = object$custom_token[[col_name]]
     )
   }
   new_data
@@ -355,14 +360,13 @@ tidy.step_tokenize <- function(x, ...) {
 }
 
 ## Implementation
-tokenizer_fun <- function(data, name, options, token, ...) {
-  check_type(data[, name], quant = FALSE)
-
-  data <- factor_to_text(data, name)
-
+tokenizer_fun <- function(x, options, token, ...) {
+  if (is.factor(x)) {
+    x <- as.character.factor(x)
+  }
   token_expr <- expr(
     token(
-      x = data[, 1, drop = TRUE]
+      x = x
     )
   )
 
@@ -370,14 +374,11 @@ tokenizer_fun <- function(data, name, options, token, ...) {
     token_expr <- rlang::call_modify(token_expr, !!!options)
   }
 
-  token_list <- eval(token_expr)
+  out <- eval(token_expr)
 
-  if (is_tokenlist(token_list)) {
-    out <- tibble::tibble(token_list)
-  } else {
-    out <- tibble::tibble(tokenlist(token_list))
+  if (!is_tokenlist(out)) {
+    out <- tokenlist(out)
   }
-  names(out) <- name
   out
 }
 
