@@ -32,50 +32,63 @@ test_that("can clean names", {
   expect_equal(tidy_exp_tr, tidy(cleaned, number = 1))
 })
 
-test_that("printing", {
-  skip_if_not_installed("janitor")
-  rec <- rec %>% step_clean_names(all_predictors())
-  expect_snapshot(print(rec))
-  expect_snapshot(prep(rec))
-})
+# Infrastructure ---------------------------------------------------------------
 
-test_that("empty selection prep/bake is a no-op", {
-  rec1 <- recipe(mpg ~ ., mtcars)
-  rec2 <- step_clean_names(rec1)
-
-  rec1 <- prep(rec1, mtcars)
-  rec2 <- prep(rec2, mtcars)
-
-  baked1 <- bake(rec1, mtcars)
-  baked2 <- bake(rec2, mtcars)
-
-  expect_identical(baked1, baked1)
-})
-
-test_that("empty selection tidy method works", {
-  rec <- recipe(mpg ~ ., mtcars)
-  rec <- step_clean_names(rec)
-
-  expect_identical(
-    tidy(rec, number = 1),
-    tibble(terms = character(), id = character())
-  )
-
-  rec <- prep(rec, mtcars)
-
-  expect_identical(
-    tidy(rec, number = 1),
-    tibble(terms = character(), id = character())
+test_that("bake method errors when needed non-standard role columns are missing", {
+  rec <- recipe(mtcars) %>%
+    step_clean_names(disp) %>%
+    update_role(disp, new_role = "potato") %>%
+    update_role_requirements(role = "potato", bake = FALSE)
+  
+  trained <- prep(rec)
+  
+  expect_error(
+    bake(trained, new_data = mtcars[, -3]),
+    class = "new_data_missing_column"
   )
 })
 
 test_that("empty printing", {
   rec <- recipe(mpg ~ ., mtcars)
   rec <- step_clean_names(rec)
-
+  
   expect_snapshot(rec)
-
+  
   rec <- prep(rec, mtcars)
-
+  
   expect_snapshot(rec)
 })
+
+test_that("empty selection prep/bake is a no-op", {
+  rec1 <- recipe(mpg ~ ., mtcars)
+  rec2 <- step_clean_names(rec1)
+  
+  rec1 <- prep(rec1, mtcars)
+  rec2 <- prep(rec2, mtcars)
+  
+  baked1 <- bake(rec1, mtcars)
+  baked2 <- bake(rec2, mtcars)
+  
+  expect_identical(baked1, baked1)
+})
+
+test_that("empty selection tidy method works", {
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_clean_names(rec)
+  
+  expect <- tibble(terms = character(), id = character())
+  
+  expect_identical(tidy(rec, number = 1), expect)
+  
+  rec <- prep(rec, mtcars)
+  
+  expect_identical(tidy(rec, number = 1), expect)
+})
+
+test_that("printing", {
+  skip_if_not_installed("janitor")
+  rec <- rec %>% step_clean_names(all_predictors())
+  
+  expect_snapshot(print(rec))
+  expect_snapshot(prep(rec))
+})
\ No newline at end of file
